@@ -186,6 +186,7 @@ define_helpers!(Helpers {
     class_apply_descriptor_destructure: (),
     class_apply_descriptor_get: (),
     class_apply_descriptor_set: (),
+    class_apply_descriptor_update: (),
     class_call_check: (),
     class_check_private_static_field_descriptor: (),
     class_extract_field_descriptor: (),
@@ -195,6 +196,10 @@ define_helpers!(Helpers {
     class_private_field_loose_base: (),
     class_private_field_loose_key: (),
     class_private_field_set: (class_extract_field_descriptor, class_apply_descriptor_set),
+    class_private_field_update: (
+        class_extract_field_descriptor,
+        class_apply_descriptor_update
+    ),
     class_private_method_get: (),
     class_private_method_init: (check_private_redeclaration),
     class_private_method_set: (),
@@ -208,6 +213,11 @@ define_helpers!(Helpers {
         class_check_private_static_field_descriptor,
         class_apply_descriptor_set
     ),
+    class_static_private_field_update: (
+        class_check_private_static_access,
+        class_check_private_static_field_descriptor,
+        class_apply_descriptor_update
+    ),
     construct: (set_prototype_of),
     create_class: (),
     decorate: (to_array, to_property_key),
